print.dissever: Prints the performance of the dissever procedure
Description
Prints the performance of the model used to do the dissever procedure.
Usage
# S3 method for dissever
print(x, ...)
Arguments
x
object of class dissever, output from the dissever function
...
Additional arguments passed to print